__version__ = "0.1.3"
__author__ = "Kura"
__email__ = "kura@kura.io"
__license__ = "MIT"
__status__ = "Stable"


__all__ = ['deiman']


from deiman import Deiman
